---
title: '[릴리즈노트] 2024-01-24 업데이트'
category: 업데이트
tags:
  - 관리자콘솔
  - 업데이트
searchTags:
  - 가상계좌 발급취소
  - 릴리즈노트
  - 업데이트
datetime: 2024-04-16T07:11:17.699Z
---

<Callout title="2024년 1월 24일 관리자콘솔 업데이트 소식을 안내드립니다." />



### **주요 업데이트 사항**

✔️ 가상계좌 발급취소/말소 API를 이용하여 가상계좌를 말소한 경우 결제실패로 분류되어 표시됩니다.

가상계좌 발급 후 입금 전에 API를 이용해 가상계좌를 말소한 경우, 관리자콘솔 \[결제 상세 내역 조회]에서 결제실패로 분류됩니다. 가상계좌 말소 건은 엑셀 다운로드시 실패 상세 항목에 계좌말소로 표시되어 구분할 수 있습니다.

✔️ 엑셀 내의 PG계정 컬럼명이 PG상점아이디(MID) 로 변경되었습니다.

\[결제 상세 내역 조회]에서 엑셀 다운로드시 기존에 PG계정으로 표시되던 컬럼명이 PG상점아이디(MID) 로 표시됩니다.

#### [\[관리자콘솔 릴리즈노트\] 2024-01-24 업데이트 보러가기↗](https://developers.portone.io/release-notes/console/2024-01-25?v=v1)
